@@ -219,29 +219,28 @@ class PriceDbApplication:
             self.price_repo = PriceRepository(self.session)
         return self.price_repo
 
+    ## Securities
+
     def get_security_list(self) -> str:
         ''' retrieve the securities from the database '''
-        repo = self.get_security_repository()
-        all = repo.query.all()
-        # sort by symbol
-        all.sort(key=lambda sec: sec.symbol)
+        from pricedb.repositories import SecurityRepository
+
+        #repo = SecurityRepository(self.session)
+        #all_symbols = repo.query.all()
+        all_symbols = self.__get_securities(None, None, None, None)
         
+        # sort by symbol
+        all_symbols.sort(key=lambda sec: sec.symbol)
+
         output = ""
-        for security in all:
+        for security in all_symbols:
             output += security.symbol + "\n"
         return output
 
-    def get_security_repository(self):
-        """ Security repository """
-        from .repositories import SecurityRepository
-
-        if not self.security_repo:
-            self.security_repo = SecurityRepository(self.session)
-        return self.security_repo
-
     def ledger_export(self):
         ''' Export prices in ledger format '''
         from pricedb.ledger import LedgerFormatter
+        from pricedb.config2 import Configuration
 
         # load all prices
         prices = self.get_prices()
@@ -251,6 +250,15 @@ class PriceDbApplication:
         # export in ledger format
         formatter = LedgerFormatter()
         result = formatter.format_prices(prices)
+
+        # If the export destination is set, save there directly.
+        cfg = Configuration()
+        dest = cfg.export_destination
+        if dest is not None:
+            self.__save_text_file(dest, result)
+            # Replace the output with the message instead.
+            result = f'Data saved in {dest}'
+
         return result
 
     def prune_all(self) -> int:
@@ -352,8 +360,14 @@ class PriceDbApplication:
 
     def __get_securities(self, currency: str, agent: str, symbol: str,
                          namespace: str) -> List[dal.Security]:
-        """ Fetches the securities that match the given filters """
-        repo = self.get_security_repository()
+        '''
+        Fetches the securities that match the given filters
+        '''
+        from .repositories import SecurityRepository
+        #from .repositories import SecurityRepositoryTiny
+
+        repo = SecurityRepository(self.session)
+        #repo = SecurityRepositoryTiny()
         query = repo.query
 
         if currency is not None:
@@ -373,3 +387,8 @@ class PriceDbApplication:
 
         securities = query.all()
         return securities
+
+    def __save_text_file(self, path: str, content: str):
+        ''' Saves a text file '''
+        with open(path, 'w') as outfile:
+            outfile.write(content)
